[llvm-commits] CVS: llvm/include/llvm/Transforms/IPO.h

Misha Brukman brukman at cs.uiuc.edu
Thu Apr 22 17:52:01 PDT 2004


Changes in directory llvm/include/llvm/Transforms:

IPO.h updated: 1.30 -> 1.31

---
Log message:

Add a boolean flag to delete this function from module, leaving the rest behind.
Useful in manual debugging when bugpoint isn't quite up to snuff.


---
Diffs of the changes:  (+4 -3)

Index: llvm/include/llvm/Transforms/IPO.h
diff -u llvm/include/llvm/Transforms/IPO.h:1.30 llvm/include/llvm/Transforms/IPO.h:1.31
--- llvm/include/llvm/Transforms/IPO.h:1.30	Sun Mar 14 14:00:37 2004
+++ llvm/include/llvm/Transforms/IPO.h	Thu Apr 22 17:51:37 2004
@@ -66,10 +66,11 @@
 
 
 //===----------------------------------------------------------------------===//
 /// createFunctionExtractionPass - This pass deletes as much of the module as
 /// possible, except for the function specified.
 ///
-Pass *createFunctionExtractionPass(Function *F);
+Pass *createFunctionExtractionPass(Function *F, bool isolateFn = true);
 
 
 //===----------------------------------------------------------------------===//
@@ -66,10 +66,11 @@
 
 //===----------------------------------------------------------------------===//
-/// createFunctionExtractionPass - This pass deletes as much of the module as
-/// possible, except for the function specified.
+/// createFunctionExtractionPass - If isolateFn is true, this pass deletes as 
+/// much of the module as possible, except for the function specified.
+/// Otherwise, it deletes the given function, leaving everything else intact.
 ///





More information about the llvm-commits mailing list